@@ -128,6 +128,9 @@ of_trafo(x[cc], scores = 5:8)
 of_trafo(x, scores = list(s1 = 5:8, s2 = 9:12))
 of_trafo(x[cc], scores = list(s1 = 5:8, s2 = 9:12))
 
+zheng_trafo(x, increment = 0.5)
+zheng_trafo(x[cc], increment = 0.5)
+
 of_trafo(ox)
 of_trafo(ox[cc])
 of_trafo(ox, scores = 5:8)
@@ -135,6 +138,9 @@ of_trafo(ox[cc], scores = 5:8)
 of_trafo(ox, scores = list(s1 = 5:8, s2 = 9:12))
 of_trafo(ox[cc], scores = list(s1 = 5:8, s2 = 9:12))
 
+zheng_trafo(ox, increment = 0.5)
+zheng_trafo(ox[cc], increment = 0.5)
+
 fmaxstat_trafo(x)
 fmaxstat_trafo(x[cc])
 fmaxstat_trafo(x, minprob = 0.49)
@@ -162,6 +168,9 @@ of_trafo(x[cc], scores = 5:8)
 of_trafo(x, scores = list(s1 = 5:8, s2 = 9:12))
 of_trafo(x[cc], scores = list(s1 = 5:8, s2 = 9:12))
 
+zheng_trafo(x, increment = 0.5)
+zheng_trafo(x[cc], increment = 0.5)
+
 of_trafo(ox)
 of_trafo(ox[cc])
 of_trafo(ox, scores = 5:8)
@@ -169,6 +178,9 @@ of_trafo(ox[cc], scores = 5:8)
 of_trafo(ox, scores = list(s1 = 5:8, s2 = 9:12))
 of_trafo(ox[cc], scores = list(s1 = 5:8, s2 = 9:12))
 
+zheng_trafo(ox, increment = 0.5)
+zheng_trafo(ox[cc], increment = 0.5)
+
 fmaxstat_trafo(x)
 fmaxstat_trafo(x[cc])
 fmaxstat_trafo(x, minprob = 0.4, maxprob = 0.51)
